#coding=utf8
__author__ = 'jjdl'

import wx
from wx import xrc
import ConfigParser
import json
import sys,os
from editor import SettingEditor

class SettingApp(wx.App):
    """

    """
    def OnInit(self):
        """

        """
        self.app_path=os.path.dirname(sys.argv[0])
        if self.app_path=="":
            self.app_path="."
        #print self.app_path

        self.resource = xrc.XmlResource(self.app_path+"/setting.xrc")
        self.frame = self.resource.LoadFrame(None, "frame_setting")

        ico = wx.Icon(self.app_path+'/icon.png', wx.BITMAP_TYPE_PNG)
        self.frame.SetIcon(ico)
 
        self.frame.Show()

        self.InitConfig()
        self.InitSavePath()
        self.BindEvents()
        return True

    def BindEvents(self):
        """
        绑定事件
        """
        self.frame.Bind(wx.EVT_BUTTON, self.OnBnSavePath, id=xrc.XRCID('bn_savepath'))
        self.frame.Bind(wx.EVT_BUTTON, self.OnBnCancel, id=xrc.XRCID("bn_cancel"))
        self.frame.Bind(wx.EVT_BUTTON, self.OnBnOK, id=xrc.XRCID("bn_ok"))
        self.frame.Bind(wx.EVT_LIST_ITEM_SELECTED, self.OnSelect, id=xrc.XRCID("listctrl_web"))
        self.frame.Bind(wx.EVT_LIST_ITEM_DESELECTED, self.OnDeSelect, id=xrc.XRCID("listctrl_web"))
        self.frame.Bind(wx.EVT_BUTTON, self.OnBnNew, id=xrc.XRCID("bn_new"))
        self.frame.Bind(wx.EVT_BUTTON, self.OnBnDelete, id=xrc.XRCID("bn_delete"))
        self.frame.Bind(wx.EVT_BUTTON, self.OnBnEdit, id=xrc.XRCID("bn_edit"))

        return


    def OnBnEdit(self, event):
        """
        编辑
        """
        listctrl_web = xrc.XRCCTRL(self.frame,  "listctrl_web")
        index = listctrl_web.GetFirstSelected()
        web = self.conf_dict[index]
        value = {"name": web, "url": self.conf.get(web, "url"), "checker": self.conf.get(web, "checker")}
        dlg = SettingEditor(self.frame, self.app_path+"/editor.xrc", value)
        if dlg.ShowModal() == wx.ID_OK:
            new_value = dlg.GetValues()
            if new_value["name"] != value["name"]:
                if self.conf.has_section(new_value["name"]):
                    wx.MessageBox("Web Name("+new_value["name"]+") Exist!", caption="Error!", style=wx.OK)
                    dlg.Destroy()
                    return

                self.conf.remove_section(value["name"])
                self.conf.add_section(new_value["name"])
            self.conf.set(new_value["name"], "url", new_value["url"])
            self.conf.set(new_value["name"], "checker", new_value["checker"])

        dlg.Destroy()
        self.UpdateWeb()
        return

    def OnBnDelete(self, event):
        """
        删除web选中项
        """
        listctrl_web = xrc.XRCCTRL(self.frame, "listctrl_web")
        index = listctrl_web.GetFirstSelected()
        self.conf.remove_section(self.conf_dict[index])
        self.UpdateWeb()
        return

    def OnBnNew(self, event):
        """
        新建web项
        """
        dlg = SettingEditor(self.frame, self.app_path+"/editor.xrc")
        if dlg.ShowModal() == wx.ID_OK:
            value = dlg.GetValues()
            if self.conf.has_section(value["name"]):
                    wx.MessageBox("Web Name("+value["name"]+") Exist!", caption="Error!", style=wx.OK)
                    dlg.Destroy()
                    return

            self.conf.add_section(value["name"])
            self.conf.set(value["name"], "url", value["url"])
            self.conf.set(value["name"], "checker", value["checker"])
            
        dlg.Destroy()
        self.UpdateWeb()

    def OnDeSelect(self, event):
        """
        未选中 listctrl_web
        """
        xrc.XRCCTRL(self.frame, "bn_edit").Enable(False)
        xrc.XRCCTRL(self.frame, "bn_delete").Enable(False)
        return

    def OnSelect(self, event):
        """
        选中listctrl_web
        """
        xrc.XRCCTRL(self.frame, "bn_edit").Enable(True)
        xrc.XRCCTRL(self.frame, "bn_delete").Enable(True)
        return


    def OnBnOK(self, event):
        """
        保存并退出
        """
        #save_path
        combobox_option = xrc.XRCCTRL(self.frame, "combobox_option")

        json_savepath = {"save_path": self.save_path,
                         "picture_option": combobox_option.GetValue()}
        f = file(self.app_path+'/save_path.json', 'w')
        json.dump(json_savepath, f)
        f.close()

        #wallpaper.conf
        with file(self.app_path+"/wallpaper.conf", "w") as f:
            self.conf.write(f)

        self.ExitMainLoop()

    def OnBnCancel(self, event):
        """
        退出
        """
        self.ExitMainLoop()

    def InitSavePath(self):
        """
        设置save path
        """
        self.save_path = json.load(file(self.app_path+"/save_path.json", 'r'))['save_path']
        pic_option = json.load(file(self.app_path+"/save_path.json", 'r'))['picture_option']
        combobox_option = xrc.XRCCTRL(self.frame, "combobox_option")
        combobox_option.SetStringSelection(pic_option)
        self.UpdateSavePath()

    def UpdateSavePath(self):
        """
        更新save_path
        """
        textctrl_savepath = xrc.XRCCTRL(self.frame, "textctrl_savepath")
        textctrl_savepath.SetValue(self.save_path)

    def OnBnSavePath(self, event):
        """
        SavePath按钮
        """
        dialog = wx.DirDialog(None, "Choose a directory:", defaultPath=self.save_path,style=wx.DD_DEFAULT_STYLE | wx.DD_NEW_DIR_BUTTON)

        if dialog.ShowModal() == wx.ID_OK:
            self.save_path = dialog.GetPath()+"/"
            self.UpdateSavePath()

        dialog.Destroy()
        return

    def UpdateWeb(self):
        """
        更新显示 listctrl_web
        """
        listctrl_web = xrc.XRCCTRL(self.frame, "listctrl_web")
        listctrl_web.ClearAll()
        listctrl_web.InsertColumn(0, 'name')
        listctrl_web.InsertColumn(1, 'url')
        self.conf_dict = {}

        for web in self.conf.sections():
            index = listctrl_web.InsertStringItem(sys.maxint, web)
            self.conf_dict[index] = web
            listctrl_web.SetStringItem(index, 0, web)
            listctrl_web.SetStringItem(index, 1, self.conf.get(web, "url"))

        listctrl_web.SetColumnWidth(0, wx.LIST_AUTOSIZE)
        listctrl_web.SetColumnWidth(1, wx.LIST_AUTOSIZE)

    def InitConfig(self):
        self.conf = ConfigParser.ConfigParser()
        self.conf.read(self.app_path+"/wallpaper.conf")
        self.UpdateWeb()



if __name__=="__main__":
    app = SettingApp()
    app.MainLoop()
